@@ -66,6 +66,7 @@ $links_show_order = $_COOKIE['links_show_order_' . COOKIEHASH];
 if ('' != $_POST['assign']) $action = 'assign';
 if ('' != $_POST['visibility']) $action = 'visibility';
 if ('' != $_POST['move']) $action = 'move';
+if ('' != $_POST['linkcheck']) $linkcheck = $_POST[linkcheck];
 
 switch ($action) {
   case 'assign':
@@ -242,7 +243,7 @@ switch ($action) {
 	  WHERE link_id=$link_id");
     } // end if save
     setcookie('links_show_cat_id_' . COOKIEHASH, $links_show_cat_id, time()+600);
-    header('Location: ' . $this_file);
+    wp_redirect($this_file);
     break;
   } // end Save
 
@@ -266,7 +267,7 @@ switch ($action) {
     }
     $links_show_cat_id = $cat_id;
     setcookie('links_show_cat_id_' . COOKIEHASH, $links_show_cat_id, time()+600);
-    header('Location: '.$this_file);
+    wp_redirect($this_file);
     break;
   } // end Delete
 
@@ -346,10 +347,10 @@ switch ($action) {
             <tr>
               <th scope="row"> <?php _e('friendship') ?> </th>
               <td>
+			    <label for="contact">
+                <input class="valinp" type="radio" name="friendship" value="contact" id="contact" <?php xfn_check('friendship', 'contact', 'radio'); ?> /> <?php _e('contact') ?></label>
                 <label for="acquaintance">
                 <input class="valinp" type="radio" name="friendship" value="acquaintance" id="acquaintance" <?php xfn_check('friendship', 'acquaintance', 'radio'); ?> />  <?php _e('acquaintance') ?></label>
-                <label for="contact">
-                <input class="valinp" type="radio" name="friendship" value="contact" id="contact" <?php xfn_check('friendship', 'contact', 'radio'); ?> /> <?php _e('contact') ?></label>
                 <label id="friend">
                 <input class="valinp" type="radio" name="friendship" value="friend" id="friend" <?php xfn_check('friendship', 'friend', 'radio'); ?> /> <?php _e('friend') ?></label>
                 <label for="friendship">
@@ -390,7 +391,7 @@ switch ($action) {
               </td>
             </tr>
             <tr>
-              <th scope="row"> family </th>
+              <th scope="row"> <?php _e('family') ?> </th>
               <td>
                 <label for="child">
                 <input class="valinp" type="radio" name="family" value="child" id="child" <?php xfn_check('family', 'child', 'radio'); ?>  />
@@ -674,11 +675,10 @@ function checkAll(form)
             $visible = ($link->link_visible == 'Y') ? __('Yes') : __('No');
             ++$i;
             $style = ($i % 2) ? ' class="alternate"' : '';
-            echo <<<LINKS
-
-    <tr valign="middle" $style>
-        <td><strong>$link->link_name</strong><br />
-LINKS;
+?>
+    <tr valign="middle" <?php echo $style; ?>>
+		<td><strong><?php echo $link->link_name; ?></strong><br />
+<?php			
         echo sprintf(__('Description: %s'), $link->link_description) . "</td>";
         echo "<td><a href=\"$link->link_url\" title=\"" . sprintf(__('Visit %s'), $link->link_name) . "\">$short_url</a></td>";
         echo <<<LINKS
@@ -752,4 +752,4 @@ LINKS;
 } // end case
 ?>
 
-<?php include('admin-footer.php'); ?>
\ No newline at end of file
+<?php include('admin-footer.php'); ?>
